<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>LXQtTrayConfiguration</name>
    <message>
        <location filename="../lxqttrayconfiguration.ui" line="6"/>
        <source>System Tray Settings</source>
        <translation>Rendszertálca beállításai</translation>
    </message>
    <message>
        <location filename="../lxqttrayconfiguration.ui" line="12"/>
        <source>General</source>
        <translation>Általános</translation>
    </message>
    <message>
        <location filename="../lxqttrayconfiguration.ui" line="18"/>
        <source>Spacing between icons:</source>
        <translation>Ikonok közötti távolság:</translation>
    </message>
    <message>
        <location filename="../lxqttrayconfiguration.ui" line="25"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../lxqttrayconfiguration.ui" line="32"/>
        <source>Sort icons by window class</source>
        <translation>Ikonok rendezése ablakosztály szerint</translation>
    </message>
</context>
</TS>
